![UDon2 logo](https://github.com/dkalpakchi/udon2/raw/master/images/udon2_logo.png "UDon2")
## Prepare your UD trees to be served!
UDon2 is a library for manipulating dependency trees in the Universal Dependencies format. Written in C++ with Python bindings through Boost.Python. Pre-compiled for Python 3.6-3.9 on Linux (both i386 and x86_64) and Python 3.7, 3.8 on Windows (win32 and win_amd64).

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)

## Documentation
Our online documentation is available at https://udon2.github.io/

## Contributing
Please check our [contribution guidelines](https://github.com/udon2/udon2/blob/master/CONTRIBUTING.md).

## Citing
The associated paper is accepted to the Universal Dependencies Workshop 2020 @ COLING 2020. If UDon2 is of any use in your research, please cite the paper.
```
@inproceedings{kalpakchi2020udon2,
  title={UDon2: a library for manipulating Universal Dependencies trees},
  author={Kalpakchi, Dmytro and Boye, Johan},
  booktitle={Proceedings of the Fourth Workshop on Universal Dependencies (UDW 2020)},
  pages={120--125},
  year={2020}
}
```
